@@ -1,6 +1,6 @@
-
 exports = module.exports = lifecycle
 exports.cmd = cmd
+exports.makeEnv = makeEnv
 
 var log = require("npmlog")
   , spawn = require("child_process").spawn
@@ -161,7 +161,9 @@ function runCmd (note, cmd, pkg, env, stage, wd, unsafe, cb) {
   var user = unsafe ? null : npm.config.get("user")
     , group = unsafe ? null : npm.config.get("group")
 
-  console.log(note)
+  if (log.level !== 'silent') {
+    console.log(note)
+  }
   log.verbose("unsafe-perm in lifecycle", unsafe)
 
   if (process.platform === "win32") {
@@ -313,6 +315,7 @@ function makeEnv (data, prefix, env) {
     var value = npm.config.get(i)
     if (value instanceof Stream || Array.isArray(value)) return
     if (!value) value = ""
+    else if (typeof value === "number") value = "" + value
     else if (typeof value !== "string") value = JSON.stringify(value)
 
     value = -1 !== value.indexOf("\n")
